@@ -412,60 +412,70 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Плеер</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="66"/>
+        <location filename="../ui/mainwindow.ui" line="67"/>
         <source>Help</source>
         <translation>Помощь</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="78"/>
+        <location filename="../ui/mainwindow.ui" line="79"/>
         <source>About</source>
         <translation>О программе</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="83"/>
+        <location filename="../ui/mainwindow.ui" line="84"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="88"/>
+        <location filename="../ui/mainwindow.ui" line="89"/>
         <source>Manage library</source>
         <translation>Управление библиотекой</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="93"/>
+        <location filename="../ui/mainwindow.ui" line="94"/>
         <source>Equalizer</source>
         <translation>Эквалайзер</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="98"/>
+        <location filename="../ui/mainwindow.ui" line="99"/>
         <source>Set timer</source>
         <translation>Установить таймер</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="103"/>
+        <location filename="../ui/mainwindow.ui" line="104"/>
         <source>Save playlist</source>
         <translation>Сохранить плейлист</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="106"/>
+        <location filename="../ui/mainwindow.ui" line="107"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="111"/>
+        <location filename="../ui/mainwindow.ui" line="112"/>
         <source>Online help</source>
         <translation>Онлайн справка</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="226"/>
+        <location filename="../ui/mainwindow.ui" line="117"/>
+        <source>Import playlists</source>
+        <translation>Импорт плейлистов</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="225"/>
         <source>Clear playlist?</source>
         <translation>Очистить плейлист?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="271"/>
         <source>Music off: </source>
         <translation>Отключение: </translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="484"/>
+        <source>Select directory</source>
+        <translation>Выбрать директорию</translation>
+    </message>
 </context>
 <context>
     <name>ManageLibraryForm</name>
@@ -506,12 +516,12 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../managelibraryform.cpp" line="145"/>
-        <source>Update selected directories? It may takes several minutes</source>
+        <source>Update selected directories? It may take several minutes</source>
         <translation>Обновить выбранные директории? Это может занять несколько минут</translation>
     </message>
     <message>
         <location filename="../managelibraryform.cpp" line="165"/>
-        <source>Update all library? It may takes a long time</source>
+        <source>Update the entire library? It may take a long time</source>
         <translation>Обновить всю библиотеку? Это может занять длительное время</translation>
     </message>
 </context>
@@ -550,45 +560,45 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../playerform.cpp" line="91"/>
-        <location filename="../playerform.cpp" line="777"/>
+        <location filename="../playerform.cpp" line="783"/>
         <source>Clear playlist</source>
         <translation>Очистить плейлист</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="92"/>
-        <location filename="../playerform.cpp" line="778"/>
+        <location filename="../playerform.cpp" line="784"/>
         <source>Delete</source>
         <translation>Удалить</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="93"/>
-        <location filename="../playerform.cpp" line="241"/>
-        <location filename="../playerform.cpp" line="281"/>
-        <location filename="../playerform.cpp" line="779"/>
+        <location filename="../playerform.cpp" line="242"/>
+        <location filename="../playerform.cpp" line="282"/>
+        <location filename="../playerform.cpp" line="785"/>
         <source>Add to favorites</source>
         <translation>В избранное</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="94"/>
-        <location filename="../playerform.cpp" line="780"/>
+        <location filename="../playerform.cpp" line="786"/>
         <source>Enqueue</source>
         <translation>В очередь</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="95"/>
-        <location filename="../playerform.cpp" line="781"/>
+        <location filename="../playerform.cpp" line="787"/>
         <source>Add to playlists</source>
         <translation>Добавить в плейлисты</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="96"/>
-        <location filename="../playerform.cpp" line="782"/>
+        <location filename="../playerform.cpp" line="788"/>
         <source>Edit tags</source>
         <translation>Редактировать теги</translation>
     </message>
     <message>
-        <location filename="../playerform.cpp" line="241"/>
-        <location filename="../playerform.cpp" line="281"/>
+        <location filename="../playerform.cpp" line="242"/>
+        <location filename="../playerform.cpp" line="282"/>
         <source>Remove from favorites</source>
         <translation>Удалить из избранного</translation>
     </message>
@@ -639,7 +649,7 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     <name>SettingsForm</name>
     <message>
         <location filename="../ui/settingsform.ui" line="14"/>
-        <location filename="../ui/settingsform.ui" line="666"/>
+        <location filename="../ui/settingsform.ui" line="671"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
@@ -677,15 +687,15 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../ui/settingsform.ui" line="174"/>
-        <location filename="../ui/settingsform.ui" line="483"/>
-        <location filename="../ui/settingsform.ui" line="570"/>
+        <location filename="../ui/settingsform.ui" line="488"/>
+        <location filename="../ui/settingsform.ui" line="575"/>
         <source>Yes</source>
         <translation>Да</translation>
     </message>
     <message>
         <location filename="../ui/settingsform.ui" line="181"/>
-        <location filename="../ui/settingsform.ui" line="490"/>
-        <location filename="../ui/settingsform.ui" line="577"/>
+        <location filename="../ui/settingsform.ui" line="495"/>
+        <location filename="../ui/settingsform.ui" line="582"/>
         <source>No</source>
         <translation>Нет</translation>
     </message>
@@ -725,47 +735,52 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Тёмный</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="412"/>
+        <location filename="../ui/settingsform.ui" line="340"/>
+        <source>Italiano</source>
+        <translation>Italiano</translation>
+    </message>
+    <message>
+        <location filename="../ui/settingsform.ui" line="417"/>
         <source>Sort album:</source>
         <translation>Сортировка альбомов:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="438"/>
+        <location filename="../ui/settingsform.ui" line="443"/>
         <source>Alphabetical</source>
         <translation>По алфавиту</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="445"/>
+        <location filename="../ui/settingsform.ui" line="450"/>
         <source>By date</source>
         <translation>По дате</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="457"/>
+        <location filename="../ui/settingsform.ui" line="462"/>
         <source>Show track length in library view:</source>
         <translation>Показывать длину трека:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="589"/>
+        <location filename="../ui/settingsform.ui" line="594"/>
         <source>Use hardware keys</source>
         <translation>Аппаратные кнопки</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="610"/>
+        <location filename="../ui/settingsform.ui" line="615"/>
         <source>Zoom keys control:</source>
         <translation>«Качелька» управляет:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="619"/>
+        <location filename="../ui/settingsform.ui" line="624"/>
         <source>Volume</source>
         <translation>Звуком</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="626"/>
+        <location filename="../ui/settingsform.ui" line="631"/>
         <source>Tracks</source>
         <translation>Треками</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="638"/>
+        <location filename="../ui/settingsform.ui" line="643"/>
         <source>Use FMTX</source>
         <translation>Включить FMTX</translation>
     </message>
@@ -800,7 +815,7 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Язык:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="550"/>
+        <location filename="../ui/settingsform.ui" line="555"/>
         <source>Pause when headphones unplugged:</source>
         <translation>Пауза при отключении наушников:</translation>
     </message>
