@@ -375,6 +375,14 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <source>Online help</source>
         <translation>在线帮助</translation>
     </message>
+    <message>
+        <source>Import playlists</source>
+        <translation>导入播放列表</translation>
+    </message>
+    <message>
+        <source>Select directory</source>
+        <translation>选择目录</translation>
+    </message>
 </context>
 <context>
     <name>ManageLibraryForm</name>
@@ -386,10 +394,6 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <source>Delete selected directories?</source>
         <translation>删除选择的目录?</translation>
     </message>
-    <message>
-        <source>Update selected directories? It may takes several minutes</source>
-        <translation>更新删除选择的目录? 这需要一些时间</translation>
-    </message>
     <message>
         <source>0 albums</source>
         <translation>0 专辑</translation>
@@ -406,14 +410,18 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <source>Added directories:</source>
         <translation>添加目录:</translation>
     </message>
-    <message>
-        <source>Update all library? It may takes a long time</source>
-        <translation>更新全部音乐库?这需要很长时间</translation>
-    </message>
     <message>
         <source>Manage library</source>
         <translation>音乐库管理</translation>
     </message>
+    <message>
+        <source>Update selected directories? It may take several minutes</source>
+        <translation>更新删除选择的目录? 这需要一些时间</translation>
+    </message>
+    <message>
+        <source>Update the entire library? It may take a long time</source>
+        <translation>更新全部音乐库?这需要很长时间</translation>
+    </message>
 </context>
 <context>
     <name>PlayerForm</name>
@@ -636,6 +644,10 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <source>Show track length in library view:</source>
         <translation>在库视图中显示音轨长度:</translation>
     </message>
+    <message>
+        <source>Italiano</source>
+        <translation>Italiano</translation>
+    </message>
 </context>
 <context>
     <name>TimerDialog</name>
