@@ -375,6 +375,14 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Settings</source>
         <translation>設定</translation>
     </message>
+    <message>
+        <source>Import playlists</source>
+        <translation>導入播放列表</translation>
+    </message>
+    <message>
+        <source>Select directory</source>
+        <translation>選擇目錄</translation>
+    </message>
 </context>
 <context>
     <name>ManageLibraryForm</name>
@@ -386,10 +394,6 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Delete selected directories?</source>
         <translation>刪除所選目錄?</translation>
     </message>
-    <message>
-        <source>Update selected directories? It may takes several minutes</source>
-        <translation>更新所選目錄? 這需要一些時間</translation>
-    </message>
     <message>
         <source>0 albums</source>
         <translation>0 專輯</translation>
@@ -406,14 +410,18 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Added directories:</source>
         <translation>添加目錄:</translation>
     </message>
-    <message>
-        <source>Update all library? It may takes a long time</source>
-        <translation>更新全部音樂庫? 這需要很長時間</translation>
-    </message>
     <message>
         <source>Manage library</source>
         <translation>音樂庫管理</translation>
     </message>
+    <message>
+        <source>Update selected directories? It may take several minutes</source>
+        <translation>更新所選目錄? 這需要一些時間</translation>
+    </message>
+    <message>
+        <source>Update the entire library? It may take a long time</source>
+        <translation>更新全部音樂庫? 這需要很長時間</translation>
+    </message>
 </context>
 <context>
     <name>PlayerForm</name>
@@ -636,6 +644,10 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Show track length in library view:</source>
         <translation>在音樂庫檢視顯示歌曲長度:</translation>
     </message>
+    <message>
+        <source>Italiano</source>
+        <translation>Italiano</translation>
+    </message>
 </context>
 <context>
     <name>TimerDialog</name>
